==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/sluzebnicesty/sluzebnicestaview.php <==
<?php
/**
 * stanislav.elbl, 23.12.2016
 */

namespace RonPortal\SluzebniCesty;

use Ron\DB\Database;
use Ron\DB\DBUtils;
use Ron\MVC\Model;
use Ron\MVC\ViewObject;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\FormReportsListView;
use RonPortal\Obdobi;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\Rozdeleni;
use RonPortal\Security;
use RonPortal\System\Report;
use RonPortal\TypRozdeleni;


class SluzebniCestaView implements ViewObject
{
    /** @var  Database */
    var $database;
    /** @var  SluzebniCesta */
    var $sluzebniCesta;
    /** @var  string */
    var $action;

    var $nazevStatu;

    /** @var TypRozdeleni */
    var $typRozdeleni;
    /** @var Rozdeleni */
    var $rozdeleni;

    /** @var TypRozdeleni */
    var $typRozdeleni2;
    /** @var Rozdeleni */
    var $rozdeleni2;

    /** @var string  vychozi stat osoby podle nastaveni nebo rozdeleni  */
    var $vychoziStatOsoby;


    function __construct($database, $sluzebniCesta, $action = 'zobrazslcestu')
    {
        $this ->database = $database;
        $this ->sluzebniCesta = $sluzebniCesta;
        $this ->action = $action;

        $this ->loadData();
    }


    function loadData()
    {
        $params = $this ->database ->createParameters();
        $sql = 'SELECT Popis FROM Stat WHERE Kod = ' . $params ->addParameter($this ->sluzebniCesta ->f_stat);
        $this ->nazevStatu = DBUtils::getSqlValue($this ->database, $sql, $params);

        if ( RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI)  &&  $this ->sluzebniCesta ->rozdeleni) {
            $this ->typRozdeleni = new TypRozdeleni();
            $this ->typRozdeleni ->load($this ->database, (int)RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI));

            $this ->rozdeleni = new Rozdeleni();
            $this ->rozdeleni ->load($this ->database, (int)$this ->sluzebniCesta ->kodTypuRozdeleni, $this ->sluzebniCesta ->rozdeleni);
        }

        $kodTypu2 = $this ->sluzebniCesta ->zahranicni
            ? RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI2Z)
            : RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI2);

        if ($kodTypu2  &&  $this ->sluzebniCesta ->rozdeleni2) {
            $this ->typRozdeleni2 = new TypRozdeleni();
            $this ->typRozdeleni2 ->load($this ->database, $kodTypu2);

            $this ->rozdeleni2 = new Rozdeleni();
            $this ->rozdeleni2 ->load($this ->database, (int)$this ->sluzebniCesta ->kodTypuRozdeleni2, $this ->sluzebniCesta ->rozdeleni2);
        }

        $this ->vychoziStatOsoby = SluzebniCestyUtils::getVychoziStatOsoby($this ->database, $this ->sluzebniCesta ->f_PP, $this ->sluzebniCesta ->datumCasOd);
    }


    /**
     * @param bool $vraceni  Urcuje, jestli ma byt viditelny formular pro zadani poznamky k vraceni
     */
    function zobrazHlavicku($vraceni = false)
    {
        Model::addData('vraceni', $vraceni);

        require('ronportal/sluzebnicesty/view_hlavicka.php');
    }


    function zobrazPovoleniNadrizeneho($uroven, $hodnota, $povolil, $datumPovoleni)
    {
        $kodPrava = 'slcesty_nadriz' . (($uroven > 1) ? $uroven : '');
        $pravaNadrizeny = Prava::vratPrava($kodPrava, $this ->sluzebniCesta ->zahranicni ? $kodPrava . '_Z' : null);
        $jeNadrizeny = $this ->sluzebniCesta ->f_PP ->lzeZobrazitPP($pravaNadrizeny, $this ->sluzebniCesta ->datumCasOd, $this ->sluzebniCesta ->datumCasDo);
        $class = 'schvaleni_sc_nadrizeny' . (($jeNadrizeny || $hodnota) ? '' : ' neschvaleno');

        echo "<div class='row $class' id='hlavickasc_schvaleninadrizeny{$uroven}'>";

        $suffix = $uroven > 1 ? '_' . $uroven : '';

        echo '<div class="col-4 col-sm-3 caption">' . TextManager::_('Nadrizeny' . $suffix) . '</div>';
        echo '<div class="col-8 col-sm-9">';

        if ($hodnota) {
            echo
                '<div class="sc_povoleno_nadrizenym">' .
                // schvaleno/zamitnuto
                (TextManager::_(($hodnota == 1) ? 'Povoleno_nadrizenym' . $suffix : 'Zamitnuto_nadrizenym' . $suffix)) .
                // datum a uzivatel
                ' ' . sprintf(TextManager::_('Datum_povoleni_nadrizenym'), date('j.n.Y', $datumPovoleni), StringUtils::htmlTextConvert($povolil)) .
                '</div>';
        }

        if ($jeNadrizeny) {
            echo '<div class="sc_povoleni_nadrizeneho">';
        }
        if ($jeNadrizeny  &&  $hodnota != 1) {    // &&  !$sluzebniCesta ->jeSchvalena() - od 5.5.2017 lze dodatecne povolit i kdyz je schvalena
            // muze nastavit povoleni => link povolit
            $keyParam = Security::csrfUrlParameter();
            echo "<a href='?menuid=sluzebnicesty&action=schvalslcestunad{$uroven}&record={$this ->sluzebniCesta->id}$keyParam'>" . TextManager::_('Povolit_nadrizenym') . '</a>';
        }

        if ($jeNadrizeny  &&  $hodnota != 2 &&  !$this ->sluzebniCesta ->jeSchvalena()) {
            // muze nastavit povoleni => link zamitnout
            $keyParam = Security::csrfUrlParameter();
            echo "<a href='?menuid=sluzebnicesty&action=zamitnislcestunad{$uroven}&record={$this ->sluzebniCesta->id}$keyParam'>" . TextManager::_('Zamitnout_nadrizenym') . '</a>';
        }

        if ($jeNadrizeny) {
            echo '</div>';
        }

        echo '</div>';

        echo "</div>\n"; // row
    }


    /**
     * @param int    $datum
     * @param string $schvalil
     * @param int    $uroven
     * @param bool   $lzeVratit
     * @param int    $datumVraceni
     */
    function zobrazSchvaleni($datum, $schvalil, $uroven, $lzeVratit, $datumVraceni) // , $jeVyssiSchvaleni
    {
        $jeVyssiSchvaleni = $this ->sluzebniCesta ->jeSchvalena($uroven + 1);
        $posloupnostZapnuta = RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_POSLOUPNOST_SCHVALOVANI);

        $prava = Prava::vratPrava("slcesty_schval$uroven", $this ->sluzebniCesta ->zahranicni ? "slcesty_schval{$uroven}_Z" : null);

        $nadpis = TextManager::_('Schvaleni_sc_' . $uroven);

        echo "<div class='row schvaleni_sc_$uroven'><div class='col col-3 caption'><span class='textschvaleni$uroven'>{$nadpis}</span></div>";
        echo "<div class='col col-9'>";

        if ($datum) {
            echo '<span class="textschvaleni' . $uroven . '">' .
                date('j.n.Y', $datum) . ' ' . StringUtils::htmlTextConvert($schvalil) . '</span>';

            if (!$prava ->priznak) {
                // nelze zrusit datum schvaleni pokud je jiz obdobi (podle $datum) uzavreno
                // (napr. pokud se proplaceji cestovni nahrady v obdobi, kdy byla SC schvalena)
                if (!$jeVyssiSchvaleni && // pokud je vyssi uroven schvaleni, tak nesmi zrusit tuto
                    $this->sluzebniCesta ->f_PP->lzeZobrazitPP($prava, $this->sluzebniCesta ->datumCasDo, $this->sluzebniCesta ->datumCasDo) &&
                    (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_EDITACE_V_UZAVRENEM)  ||  !Obdobi::jeObdobiUzavreno($this ->database, 'ADS', $datum, $datum))
                ) {
                    $strOdschvalit = TextManager::_('Zrusit_schvaleni_sc_' . $uroven);
                    $keyParam = Security::csrfUrlParameter();
                    echo "<span class='margin-left-2'><a href='?menuid=sluzebnicesty&action=zrusschvalenislcesty$uroven&record={$this->sluzebniCesta ->id}$keyParam'>$strOdschvalit</a></span>";
                }
            }
        } else {
            if ( (!$posloupnostZapnuta || $lzeVratit  ||  $uroven == 1)  &&  $this ->sluzebniCesta ->f_PP ->lzeZobrazitPP($prava, $this ->sluzebniCesta ->datumCasOd, $this ->sluzebniCesta ->datumCasDo)) {
                $strSchvalit = TextManager::_('Schvalit_sc_' . $uroven);
                $keyParam = Security::csrfUrlParameter();

                echo "<a href='?menuid=sluzebnicesty&action=schvalslcestu$uroven&record={$this ->sluzebniCesta ->id}$keyParam'>$strSchvalit</a>";

                if (RonPortalSettings::getIntValue(SluzebniCestyController::SETTINGS_POUZIVAT_VRACENI) && $lzeVratit) {
                    echo '<span style="display:inline-block; width:50px;"></span>'; // mezera

                    $keyParam = Security::csrfUrlParameter();
                    echo "<a href='?menuid=sluzebnicesty&action=vratslcestu&record={$this ->sluzebniCesta ->id}$keyParam' class='vraceni_sluzebni_cesty_link'>" . TextManager::_('Vratit_sc') . "</a>";
                }
            }

            if ($datumVraceni  &&  ($uroven == 1  || $this ->sluzebniCesta ->jeSchvalena($uroven - 1))) {
                if ($this ->sluzebniCesta ->poznamkaKVraceni) {
                    echo '<div class="poznamkaKVraceni">' . StringUtils::htmlTextConvert($this ->sluzebniCesta ->poznamkaKVraceni) . ' (' . StringUtils::format('datetime', $datumVraceni) . ')</div>';
                }
            }
        }

        echo "</div></div>\n";
    }


    function zobrazRadky()
    {
        echo "<div id='RadkySluzebniCestyView'>\n";
        if (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_KOMPAKTNI_RADKY)) {
            $radky = KompaktniRadekSluzebniCesty::nactiKompaktniRadkySC($this ->database, $this ->sluzebniCesta);

            if ( $radky && sizeof($radky) ) {
                $sluzebniCesta = $this ->sluzebniCesta;
                require('ronportal/sluzebnicesty/view_radky_kompaktni.php');
            }
        } else {
            RadekSluzebniCestyBrowser::zobrazRadkySluzebniCesty($this ->database, $this ->sluzebniCesta, $this ->sluzebniCesta ->lzeEditovat, $this ->action);
        }
        echo "</div>\n";
    }


    function zobrazExterniOdkazy()
    {
        $text = RonPortalSettings::getMultilineValue('slcesty_dalsihtml');
        if (!$text) {
            return;
        }

        $text = str_ireplace(
            ['%id%', '%datumod%', '%datumdo%', '%idpp%', '%osobnicislo%'],
            [
                $this ->sluzebniCesta ->id,
                date('dmY', $this ->sluzebniCesta ->datumCasOd), date('dmY', $this ->sluzebniCesta ->datumCasDo),
                $this ->sluzebniCesta ->f_PP ->idPP, $this ->sluzebniCesta ->f_PP ->osobniCislo
            ],
            $text
        );

        echo '<div id="sc_externi_odkazy">' .$text . '</div>';
    }


    public function render()
    {
        //$this ->sluzebniCesta ->zobrazSluzebniCestu($this ->database, $this ->action);

        $this ->sluzebniCesta ->lzeEditovat = $this ->sluzebniCesta->lzeEditovatSluzebniCestu($this ->database, false); // nezobrazovat chyby
        $this ->sluzebniCesta ->lzeEditovatHlavicku = $this ->sluzebniCesta ->lzeEditovatHlavicku($this ->database);

        $this ->zobrazHlavicku($this ->action == 'vratslcestu');

        // Sestavy
        //$reportList = RonPortalReport::loadFormReportsByName($this ->database, 'SluzebniCesta');
        $reportList = Report::loadFormReports($this ->database, 'SluzebniCesta', 'SluzebniCesta'); // pro kompatibilitu zobrazuje i reporty s kodem SluzebniCesta...
        FormReportsListView::renderReportList($reportList, '?menuid=sluzebnicesty&action=report&idslcesty=' . $this ->sluzebniCesta ->id);

        $this ->zobrazRadky();

        echo "<div id='UctovaniSluzebniCestyView'>\n";
        RadekUctovaniSluzebniCestyBrowser::zobrazUctovani($this ->database, $this ->sluzebniCesta, $this ->action);
        echo "</div>\n";

        // Dokumenty
        echo "<div id='DokumentySluzebniCestyView'>\n";
        DokumentySCBrowser::zobrazDokumentySlCesty($this ->database, $this ->sluzebniCesta ->id, $this->sluzebniCesta ->f_PP ->rc, $this ->sluzebniCesta ->lzeEditovat);
        echo "</div>\n";

        // Externi odkazy
        $this ->zobrazExterniOdkazy();

        echo "<div class='normaltext margin-top-2         '><a href='?menuid=sluzebnicesty'>" . TextManager::_('Zpet_na_seznam') . "</a></div>\n";

        $f = new RadekSluzebniCestyDialog($this ->database, $this ->sluzebniCesta);
        $f ->render();

        $f = new RadekUctovaniSCDialog($this ->database, $this ->sluzebniCesta);
        $f ->render();
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/sluzebnicesty/sluzebnicestaview.php <==
<?php
/**
 * stanislav.elbl, 23.12.2016
 */

namespace RonPortal\SluzebniCesty;

use Ron\DB\Database;
use Ron\DB\DBUtils;
use Ron\Http\Csrf;
use Ron\MVC\Model;
use Ron\MVC\ViewObject;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\FormReportsListView;
use RonPortal\Obdobi;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\Rozdeleni;
use RonPortal\System\Report;
use RonPortal\TypRozdeleni;


class SluzebniCestaView implements ViewObject
{
    /** @var  Database */
    var $database;
    /** @var  SluzebniCesta */
    public $sluzebniCesta;
    /** @var  string */
    public $action;

    public $nazevStatu;

    /** @var TypRozdeleni */
    public $typRozdeleni;
    /** @var Rozdeleni */
    public $rozdeleni;

    /** @var TypRozdeleni */
    public $typRozdeleni2;
    /** @var Rozdeleni */
    public $rozdeleni2;

    /** @var string  vychozi stat osoby podle nastaveni nebo rozdeleni  */
    public $vychoziStatOsoby;

    /** @var Spolucestujici[] */
    public $spolucestujici;

    /** @var PredpokladanyVydajSC[] */
    public $predpokladaneNaklady;


    function __construct($database, $sluzebniCesta, $action = 'zobrazslcestu')
    {
        $this ->database = $database;
        $this ->sluzebniCesta = $sluzebniCesta;
        $this ->action = $action;

        $this ->loadData();
    }


    function loadData()
    {
        $params = $this ->database ->createParameters();
        $sql = 'SELECT Popis FROM Stat WHERE Kod = ' . $params ->addParameter($this ->sluzebniCesta ->f_stat);
        $this ->nazevStatu = DBUtils::getSqlValue($this ->database, $sql, $params);

        if ( RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI)  &&  $this ->sluzebniCesta ->rozdeleni) {
            $this ->typRozdeleni = new TypRozdeleni();
            $this ->typRozdeleni ->load($this ->database, (int)RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI));

            $this ->rozdeleni = new Rozdeleni();
            $this ->rozdeleni ->load($this ->database, (int)$this ->sluzebniCesta ->kodTypuRozdeleni, $this ->sluzebniCesta ->rozdeleni);
        }

        $kodTypu2 = $this ->sluzebniCesta ->zahranicni
            ? RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI2Z)
            : RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI2);

        if ($kodTypu2  &&  $this ->sluzebniCesta ->rozdeleni2) {
            $this ->typRozdeleni2 = new TypRozdeleni();
            $this ->typRozdeleni2 ->load($this ->database, $kodTypu2);

            $this ->rozdeleni2 = new Rozdeleni();
            $this ->rozdeleni2 ->load($this ->database, (int)$this ->sluzebniCesta ->kodTypuRozdeleni2, $this ->sluzebniCesta ->rozdeleni2);
        }

        $this ->vychoziStatOsoby = SluzebniCestyUtils::getVychoziStatOsoby($this ->database, $this ->sluzebniCesta ->f_PP, $this ->sluzebniCesta ->datumCasOd);

        $this ->spolucestujici = Spolucestujici::nactiSpolucestujici($this ->database, $this ->sluzebniCesta ->id);
        $this ->predpokladaneNaklady = PredpokladanyVydajSC::nactiPredpokladaneVydaje($this ->database, $this ->sluzebniCesta ->id);
    }


    /**
     * @param bool $vraceni  Urcuje, jestli ma byt viditelny formular pro zadani poznamky k vraceni
     */
    function zobrazHlavicku($vraceni = false)
    {
        Model::addData('vraceni', $vraceni);

        require('ronportal/sluzebnicesty/view_hlavicka.php');
    }


    function zobrazPovoleniNadrizeneho($uroven, $hodnota, $povolil, $datumPovoleni)
    {
        $kodPrava = 'slcesty_nadriz' . (($uroven > 1) ? $uroven : '');
        $pravaNadrizeny = Prava::vratPrava($kodPrava, $this ->sluzebniCesta ->zahranicni ? $kodPrava . '_Z' : null);
        $jeNadrizeny = $this ->sluzebniCesta ->f_PP ->lzeZobrazitPP($pravaNadrizeny, $this ->sluzebniCesta ->datumCasOd, $this ->sluzebniCesta ->datumCasDo);
        $class = 'schvaleni_sc_nadrizeny' . (($jeNadrizeny || $hodnota) ? '' : ' neschvaleno');

        echo "<div class='row $class' id='hlavickasc_schvaleninadrizeny{$uroven}'>";

        $suffix = $uroven > 1 ? '_' . $uroven : '';

        echo '<div class="col-4 col-sm-3 caption">' . TextManager::_('Nadrizeny' . $suffix) . '</div>';
        echo '<div class="col-8 col-sm-9">';

        if ($hodnota) {
            echo
                '<div class="sc_povoleno_nadrizenym">' .
                // schvaleno/zamitnuto
                (TextManager::_(($hodnota == 1) ? 'Povoleno_nadrizenym' . $suffix : 'Zamitnuto_nadrizenym' . $suffix)) .
                // datum a uzivatel
                ' ' . sprintf(TextManager::_('Datum_povoleni_nadrizenym'), date('j.n.Y', $datumPovoleni), StringUtils::htmlTextConvert($povolil)) .
                '</div>';
        }

        if ($jeNadrizeny) {
            echo '<div class="sc_povoleni_nadrizeneho">';
        }
        if ($jeNadrizeny  &&  $hodnota != 1) {    // &&  !$sluzebniCesta ->jeSchvalena() - od 5.5.2017 lze dodatecne povolit i kdyz je schvalena
            // muze nastavit povoleni => link povolit
            $keyParam = Csrf::csrfUrlParameter();
            echo "<a href='?menuid=sluzebnicesty&action=schvalslcestunad{$uroven}&record={$this ->sluzebniCesta->id}$keyParam'>" . TextManager::_('Povolit_nadrizenym') . '</a>';
        }

        if ($jeNadrizeny  &&  $hodnota != 2 &&  !$this ->sluzebniCesta ->jeSchvalena()) {
            // muze nastavit povoleni => link zamitnout
            $keyParam = Csrf::csrfUrlParameter();
            echo "<a href='?menuid=sluzebnicesty&action=zamitnislcestunad{$uroven}&record={$this ->sluzebniCesta->id}$keyParam'>" . TextManager::_('Zamitnout_nadrizenym') . '</a>';
        }

        if ($jeNadrizeny) {
            echo '</div>';
        }

        echo '</div>';

        echo "</div>\n"; // row
    }


    /**
     * @param int    $datum
     * @param string $schvalil
     * @param int    $uroven
     * @param bool   $lzeVratit
     * @param int    $datumVraceni
     */
    function zobrazSchvaleni($datum, $schvalil, $uroven, $lzeVratit, $datumVraceni) // , $jeVyssiSchvaleni
    {
        $jeVyssiSchvaleni = $this ->sluzebniCesta ->jeSchvalena($uroven + 1);
        $posloupnostZapnuta = RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_POSLOUPNOST_SCHVALOVANI);

        $prava = Prava::vratPrava("slcesty_schval$uroven", $this ->sluzebniCesta ->zahranicni ? "slcesty_schval{$uroven}_Z" : null);

        $nadpis = TextManager::_('Schvaleni_sc_' . $uroven);

        echo "<div class='row schvaleni_sc_$uroven'><div class='col col-3 caption'><span class='textschvaleni$uroven'>{$nadpis}</span></div>";
        echo "<div class='col col-9'>";

        if ($datum) {
            echo '<span class="textschvaleni' . $uroven . '">' .
                date('j.n.Y', $datum) . ' ' . StringUtils::htmlTextConvert($schvalil) . '</span>';

            if (!$prava ->priznak) {
                // nelze zrusit datum schvaleni pokud je jiz obdobi (podle $datum) uzavreno
                // (napr. pokud se proplaceji cestovni nahrady v obdobi, kdy byla SC schvalena)
                if (!$jeVyssiSchvaleni && // pokud je vyssi uroven schvaleni, tak nesmi zrusit tuto
                    $this->sluzebniCesta ->f_PP->lzeZobrazitPP($prava, $this->sluzebniCesta ->datumCasDo, $this->sluzebniCesta ->datumCasDo) &&
                    (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_EDITACE_V_UZAVRENEM)  ||  !Obdobi::jeObdobiUzavreno($this ->database, 'ADS', $datum, $datum))
                ) {
                    $strOdschvalit = TextManager::_('Zrusit_schvaleni_sc_' . $uroven);
                    $keyParam = Csrf::csrfUrlParameter();
                    echo "<span class='margin-left-2'><a href='?menuid=sluzebnicesty&action=zrusschvalenislcesty$uroven&record={$this->sluzebniCesta ->id}$keyParam'>$strOdschvalit</a></span>";
                }
            }
        } else {
            if ( (!$posloupnostZapnuta || $lzeVratit  ||  $uroven == 1)  &&  $this ->sluzebniCesta ->f_PP ->lzeZobrazitPP($prava, $this ->sluzebniCesta ->datumCasOd, $this ->sluzebniCesta ->datumCasDo)) {
                $strSchvalit = TextManager::_('Schvalit_sc_' . $uroven);
                $keyParam = Csrf::csrfUrlParameter();

                echo "<a href='?menuid=sluzebnicesty&action=schvalslcestu$uroven&record={$this ->sluzebniCesta ->id}$keyParam'>$strSchvalit</a>";

                if (RonPortalSettings::getIntValue(SluzebniCestyController::SETTINGS_POUZIVAT_VRACENI) && $lzeVratit) {
                    echo '<span style="display:inline-block; width:50px;"></span>'; // mezera

                    $keyParam = Csrf::csrfUrlParameter();
                    echo "<a href='?menuid=sluzebnicesty&action=vratslcestu&record={$this ->sluzebniCesta ->id}$keyParam' class='vraceni_sluzebni_cesty_link'>" . TextManager::_('Vratit_sc') . "</a>";
                }
            }

            if ($datumVraceni  &&  ($uroven == 1  || $this ->sluzebniCesta ->jeSchvalena($uroven - 1))) {
                if ($this ->sluzebniCesta ->poznamkaKVraceni) {
                    echo '<div class="poznamkaKVraceni">' . StringUtils::htmlTextConvert($this ->sluzebniCesta ->poznamkaKVraceni) . ' (' . StringUtils::format('datetime', $datumVraceni) . ')</div>';
                }
            }
        }

        echo "</div></div>\n";
    }


    function zobrazRadky()
    {
        echo "<div id='RadkySluzebniCestyView'>\n";
        if (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_KOMPAKTNI_RADKY)) {
            $radky = KompaktniRadekSluzebniCesty::nactiKompaktniRadkySC($this ->database, $this ->sluzebniCesta);

            if ( $radky && sizeof($radky) ) {
                $sluzebniCesta = $this ->sluzebniCesta;
                require('ronportal/sluzebnicesty/view_radky_kompaktni.php');
            }
        } else {
            RadekSluzebniCestyBrowser::zobrazRadkySluzebniCesty($this ->database, $this ->sluzebniCesta, $this ->sluzebniCesta ->lzeEditovat, $this ->action);
        }
        echo "</div>\n";
    }


    function zobrazExterniOdkazy()
    {
        $text = RonPortalSettings::getMultilineValue('slcesty_dalsihtml');
        if (!$text) {
            return;
        }

        $text = str_ireplace(
            ['%id%', '%datumod%', '%datumdo%', '%idpp%', '%osobnicislo%'],
            [
                $this ->sluzebniCesta ->id,
                date('dmY', $this ->sluzebniCesta ->datumCasOd), date('dmY', $this ->sluzebniCesta ->datumCasDo),
                $this ->sluzebniCesta ->f_PP ->idPP, $this ->sluzebniCesta ->f_PP ->osobniCislo
            ],
            $text
        );

        echo '<div id="sc_externi_odkazy">' .$text . '</div>';
    }


    public function render()
    {
        //$this ->sluzebniCesta ->zobrazSluzebniCestu($this ->database, $this ->action);

        $this ->sluzebniCesta ->lzeEditovat = $this ->sluzebniCesta->lzeEditovatSluzebniCestu($this ->database, false); // nezobrazovat chyby

        $this ->zobrazHlavicku($this ->action == 'vratslcestu');

        // Sestavy
        //$reportList = RonPortalReport::loadFormReportsByName($this ->database, 'SluzebniCesta');
        $reportList = Report::loadFormReports($this ->database, 'SluzebniCesta', 'SluzebniCesta'); // pro kompatibilitu zobrazuje i reporty s kodem SluzebniCesta...
        FormReportsListView::renderReportList($reportList, '?menuid=sluzebnicesty&action=report&idslcesty=' . $this ->sluzebniCesta ->id);

        $this ->zobrazRadky();

        echo "<div id='UctovaniSluzebniCestyView'>\n";
        RadekUctovaniSluzebniCestyBrowser::zobrazUctovani($this ->database, $this ->sluzebniCesta);
        echo "</div>\n";

        // Dokumenty
        echo "<div id='DokumentySluzebniCestyView'>\n";
        DokumentySCBrowser::zobrazDokumentySlCesty($this ->database, $this ->sluzebniCesta ->id, $this->sluzebniCesta ->f_PP ->rc, $this ->sluzebniCesta ->lzeEditovat);
        echo "</div>\n";

        // Externi odkazy
        $this ->zobrazExterniOdkazy();

        echo "<div class='normaltext margin-top-2         '><a href='?menuid=sluzebnicesty'>" . TextManager::_('Zpet_na_seznam') . "</a></div>\n";

        $f = new RadekSluzebniCestyDialog($this ->database, $this ->sluzebniCesta);
        $f ->render();

        $f = new RadekUctovaniSCDialog($this ->database, $this ->sluzebniCesta);
        $f ->render();
    }
}
